@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this library; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
 """
     pyudev._ctypeslib.libc
     ======================
@@ -33,14 +32,8 @@ from ctypes import c_int
 
 from ._errorcheckers import check_errno_on_nonzero_return
 
+FD_PAIR = c_int * 2
 
-fd_pair = c_int * 2
+SIGNATURES = dict(pipe2=([FD_PAIR, c_int], c_int), )
 
-
-SIGNATURES = dict(
-   pipe2=([fd_pair, c_int], c_int),
-)
-
-ERROR_CHECKERS = dict(
-   pipe2=check_errno_on_nonzero_return,
-)
+ERROR_CHECKERS = dict(pipe2=check_errno_on_nonzero_return, )
